/*---[ parse.h ]----------------------------------------------------
 * Copyright (C) 2000 Tomas Junnonen (majix@sci.fi)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * The text file parse function headers.
 *--------------------------------------------------------------------*/

#ifndef _FIRESTARTER_PARSE
#define _FIRESTARTER_PARSE

#include <config.h>
#include <gnome.h>
#include "firestarter.h"

Hit *parse_log_line (gchar *line);

void parse_all_rules (void);
void parse_trusted_hosts (void);
void parse_blocked_hosts (void);
void parse_open_ports (void);
void parse_stealthed_ports (void);
void parse_blocked_ports (void);
void parse_forward (void);

#endif
